==> jmb.fax-0.2.tar.gz: jmb.fax-0.2/jmb/fax/bin/hylafax.py <==
#!/usr/bin/python
# coding: utf-8
## FIXME: questo modulo è una gran confusione e va sistemato
"""

Fax in ricezione
================

Alla fine di ogni ricezione viene eseguito direttamente da hylafax:
bin/faxrcvd "recvq/fax000000235.tif" "ttyS1" "000000509" "" "" ""
(ad esempio)

Di conseguenza questo script e' chiamato dal file bin/faxrcvd (bash
script, ultima riga, l'unica modifica fatta rispetto alla versione
orginale hylafax).

Recuperando da bin/faxrcvd solo la variabile $COMMID si esegue:
bin/hylafax.py -v -s django.settings -i -c $COMMID

Fax in invio
============

Hylafax si comporta (molto) diversamente per i fax in invio.
Ad ogni tentativo di invio viene creato un file di log in log/ .

Soltanto quando l'invio e' terminato viene chiamato lo script notify
con unico argomento il file contenente le informazioni sull'invio.
Questo file e' built-in di hylafax e risiede nella directory doneq/
nel formato q$JOBID (esempio doneq/q890).

Nonostante questo file contenga gia' numerose informazioni sul fax in
questione, si preferisce recuperarne solo il commid per poi parsare
il log 'grezzo' in log/ cosi' come succede per i fax ricevuti.

Exit Status
===========

Passato da bin/notify (solo fax inviati) può essere:

* Killed = job interrotto dall'utente con faxrm
* done = fax inviato
* failed = fax non inviato

.. autofunction:: get_fax

.. .. autofunction:: parse_log

.. .. autofunction:: get_info_from_queue

.. .. autofunction:: parse_row_line


"""

USAGE ="""
  usage: %prog [options]
  -s, --settings=file: settings file eg: jobs.settings
  -d, --dryrun: don't really touch the db
  -v, --verbose: can't you immagine?
  -q, --queue=id: relative queue file path (outgoing fax, ex doneq/q890)
  -c, --commid=id: commid (incoming fax, ex c000003174)
  -r, --root=root: set root dir
  -x, --exit=exit: exit status passed by hylafax
  -t, --to_do=to_do: a chiedere a Giacomo
  -n, --non_so=non_so: a chiedere a Giacomo
"""

import os
import re
import sys
import csv
import commands
import logging
import logging.handlers
from datetime import datetime
import datetime as d

from django.conf import settings
from django.core.mail import EmailMessage

from jmb.core.utils import optionparse
from jmb.fax.models import Fax, FaxNumber

HYLA_ROOT  = '/var/spool/hylafax/'
LOG_DIR    = HYLA_ROOT + 'log/'
RECV_DIR   = HYLA_ROOT + 'recvq/'
PDF_DIR    = settings.FAX_PATH_DOCUMENTS

DATE_FORMAT='%b %d %H:%M:%S'
today = d.date.today().strftime('%y%m%d')
rec_filename=''

PATTERN_OUT_STATUS = "(status)?(error)?"
out_status = re.compile(PATTERN_OUT_STATUS)

PATTERN_IN_RECV = ".{15,15}.*RECV FAX \(.*\)\: recvq\/(?P<file>.*) from (?P<sender>.*)\,.*, (?P<pages>.*) pages? in (?P<duration>.*)"
PATTERN_IN_RECIPIENT = ".{15,15}.*SESSION BEGIN.* .* (?P<recipient_number>.*)"
PATTERN_IN_DEVICE = ".{15,15}.*recvq/(?P<file>.*fax\d+.tif).*(?P<device>tty\w+?\d+?)\" "
PATTERN_IN_SENDER = '.{15,15}.*CallID.* "(?P<sender_number>.*)" ".*" ".*" ".*"$'

in_recv = re.compile(PATTERN_IN_RECV)
in_recipient = re.compile(PATTERN_IN_RECIPIENT)
in_device = re.compile(PATTERN_IN_DEVICE)
in_sender = re.compile(PATTERN_IN_SENDER)

DATE_FORMAT='%b %d %H:%M:%S'

FAX_VIA_MAIL_NOTIFY_TO_USER = settings.FAX_VIA_MAIL_NOTIFY_TO_USER

MAIL_BODY_SENT = """
Recipient: %s
Subject: %s
Job ID: %s
Sent Date: %s
Sent Confirm: %s
Sent Time: %s
Sent Pages: %s
"""

MAIL_BODY_RCV = """
Sender: %s
Sender Number: %s
Job ID: %s
Received Date: %s
Received Time: %s
Received Pages: %s
"""

# FIXME! un file di log in /tmp!!!!
HYLAFAX_LOG_FILENAME = '/tmp/hylafax.log'



def get_fax():
    """Ritorna una istanza di fax.models.Fax del fax ricevuto o da spedire 
    a seconda del valore di ``opt.queue``
    """

    if opt.queue:
        jlogger.debug("Fax Inviato : opt.queue : %s, job : %s" % (opt.queue, opt.queue.split('/q')))
        fax = Fax.objects.get(job=opt.queue.split('/q').pop())
    else:
        jlogger.debug("Fax Ricevuto")
        fax = Fax()
    return fax

def parse_log(fax):
    if opt.queue: # viene passato es. doneq/q10
        log_file_name = os.path.join(HYLA_ROOT, opt.queue)
    else: # viene passato es. c0000010
        log_file_name = os.path.join(LOG_DIR, opt.commid)
        fax.date_create = datetime.fromtimestamp(os.path.getmtime(log_file_name))
    log = open(log_file_name)

    print "Log file name: %s " % log_file_name
    fax.date_last_modify = datetime.fromtimestamp(os.path.getmtime(log_file_name))
    fax.date_sent = datetime.fromtimestamp(os.path.getmtime(log_file_name))
    if opt.queue:
        info = get_info_from_queue(log)
        if opt.exit == 'killed':
            fax.job = ''
            fax.duration = ''
        else:
            fax.job = 'c' + info['commid']
            if info['commid']:
                duration, sender = get_time_and_sender(info['commid'])
            else:
                duration = sender = None
            fax.duration = duration
            fax.sender = sender
        fax.pages = info['totpages']

        if opt.exit == 'done':
            fax.status = 4
        else:
            fax.status = 5
            fax.error = info['status'] or 'Killed'
    else:
        for line in log:
            parse_raw_line(line)


def get_time_and_sender(filename):
    filename = "c%s" % (filename,)
    f = open(os.path.join(LOG_DIR, filename))
    sender = duration = None

    for line in f:
        m = re.search('SEND FAX.*FROM.*docq.*sent in (?P<time>.*)\)', line)
        if m:
            duration = m.group('time')

        m = re.search('SEND FAX: JOB.*FROM.*@(?P<sender>.*)>.*$', line)
        if m:
            sender = m.group('sender')

    return duration, sender


def get_info_from_queue(log):
    info = {}
    for line in log:
        line = line.rstrip('\n')
        try:
            key = line[:line.find(':')]
            val = line[line.find(':')+1:]
            info[key] = val
        except:
            pass
    return info

# FAX OK
# sdest         #### destinatario
# stty          #### device modem in uscita
# ssend         #### numero mittente
#commid
#totpages

# scommid       #### id log fax (c000000001)
# stime         #### data e ora tentativo spedizione
# sdest         #### destinatario
# ssend         #### mittente
# stty          #### device modem in uscita
# serror        #### errore del fax


def parse_raw_line(line):
    global rec_filename

    m = in_recv.match(line)
    find_information = False

    if m:
        find_information = True
        rec_filename = m.group('file')
        #c = m.group('sender')
        #tmp = c
        #for char in ('.', ' ', '|', '-', '/', '\\'):
        #    tmp = tmp.replace(char, '')
        #tmp = tmp.replace('+','00')
        #if tmp.isdigit():
        #    fax.sender_number = tmp[:16]
        #    fax.sender = c[:100]
        #else:
        fax.sender = m.group('sender')
        fax.pages = m.group('pages')
        fax.duration = m.group('duration')

    m = in_recipient.search(line)
    if m:
        fax.recipient_number = m.group('recipient_number')

    m = in_device.search(line)
    if m:
        fax.device = m.group('device')

        # Ogni tanto ho notato che la riga in_recv non c'e e quindi ad alcuni fax
        # non viene associato il file e il numero di pagine. Quindi se non viene trovato
        # il file nella linea in_recv allora provo anche nella riga in_device
        # che sembra esserci sempre (da qua riesco solo a ricavare il nome del file e non
        # il numero di pagine)
        if not find_information:
            rec_filename = m.group('file')

    m = in_sender.search(line)
    if m:
        fax.sender_number = m.group('sender_number')

    fax.job = opt.commid
    fax.cover = False
    fax.status = 2
    fax.subject = 'fax ricevuto'
    fax.read = 0

### PROGRAM
if __name__ == '__main__':

    opt, args = optionparse.parse(USAGE)
    os.environ['DJANGO_SETTINGS_MODULE'] = opt.settings

    if opt.root:
        HYLA_ROOT = opt.root
        print "Attenzione root impostata a " + opt.root

    # Set up a specific logger with our desired output level
    jlogger = logging.getLogger('JumboDocLogger')
    jlogger.setLevel(logging.DEBUG)

    # Add the log message handler to the logger
    handler = logging.handlers.RotatingFileHandler(
                  HYLAFAX_LOG_FILENAME, maxBytes=4194304, backupCount=5)

    # create formatter
    formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
    # add formatter to handler
    handler.setFormatter(formatter)
    jlogger.addHandler(handler)

    jlogger.debug("------ INIZIO SCRIPT HYLAFAX -------")


    fax = get_fax()
    parse_log(fax)

    # se fax inviato, la conferma invio la si recupera da fax.status
    if fax.status == 4:
        mail_status = 'OK'
    else:
        mail_status = fax.error

    for i in fax._meta.fields:
        print i.name, getattr(fax, i.name)
        #print fax.status

    if not opt.dryrun:
        from django.conf import settings

        fax.save()
        if opt.commid:
            fax.file = '%s%s_%s.pdf' % (PDF_DIR, today, fax.id)
            fax.save()
            cmd = "umask 022; tiff2pdf -o %s %s%s" % (fax.file.path, RECV_DIR, rec_filename)
            #cmd = "umask 022; tiff2ps -a %s%s | /usr/bin/ps2pdf - %s" % (RECV_DIR, rec_filename, fax.file.path)
            print "eseguo " + cmd
            status, output = commands.getstatusoutput(cmd)

        info = {'operator'  : fax.sender_number,
                'pdf_dir'   : PDF_DIR,
                'file'      : fax.file,
                }

        data_fax = fax.date_last_modify.strftime('%d/%m/%Y %H:%M:%S')

        subject_fax = settings.FAX_SUBJECT
        from_fax = settings.FAX_FROM

        recipient_list = FaxNumber.get_notifiers_in(device=fax.device)

        # INVIO MAIL PER FAX RICEVUTI
        if opt.commid:
            if device_number and device_number.send_at_received_fax and recipient_list:
                mittente = ""
                if fax.sender:
                    mittente += "%s" % (fax.sender,)
                if fax.sender_number:
                    mittente += " - %s" % (fax.sender_number,)

                subject = '%sReceived fax of %s from %s' % (subject_fax, data_fax, mittente)
                from_email = 'Report Fax %s' % (from_fax,)
                #hyla_mail_receipt = settings.HYLA_MAIL_RECEIPT
                #recipient_list = hyla_mail_receipt.get(fax.device, [])
                #if recipient_list:
                body_message = MAIL_BODY_RCV % (fax.sender, fax.sender_number, fax.job, data_fax, fax.duration, fax.pages)

                email = EmailMessage(subject, body_message, from_email, recipient_list)
                email.attach_file(fax.file.path)
                email.send()

        # INVIO MAIL PER FAX INVIATI
        else:
            send_sent_mail = False
            sent_recipient_list = set()

            # Se si e' abilitata la notifica via mail per i fax mandati via mail
            # controllo che il fax sia di tipo "mandato via mail", e in caso positivo
            # aggungo nei destinatari il suubmitter del fax.
            if settings.FAX_VIA_MAIL_NOTIFY_TO_USER and fax.sent_by == 'M':
                if fax.submitter.email:
                    sent_recipient_list.add(fax.submitter.email.strip())
                    send_sent_mail = True

            # Se e' stata abilitata anche la conferma di ogni invio dei fax a determinati
            # inidirizzi unisco le varie mail
            if device_number and device_number.send_at_sent_fax and recipient_list:
                sent_recipient_list = sent_recipient_list.union(recipient_list)
                send_sent_mail = True

            if send_sent_mail:
                dest = "%s" % fax.recipient_number
                if fax.recipient:
                    dest = "%s (%s)" % (fax.recipient, fax.recipient_number)
                subject = '%sSent Report - %s - %s - %s' % (subject_fax, dest, fax.subject, data_fax)
                from_email = 'Report Fax %s' % (from_fax,)
                #recipient_list = settings.HYLA_MAIL_RECEIPT
                #if recipient_list:
                body_message = MAIL_BODY_SENT % (dest, fax.subject, fax.job, data_fax, mail_status, fax.duration, fax.pages)

                email = EmailMessage(subject, body_message, from_email, sent_recipient_list)
                email.attach_file(fax.file.path)
                email.send()

==> jmb.fax-0.6.tar.gz: jmb.fax-0.6/jmb/fax/bin/hylafax.py <==
#!/usr/bin/python
# coding: utf-8
## FIXME: questo modulo è una gran confusione e va sistemato
"""

Fax in ricezione
================

Alla fine di ogni ricezione viene eseguito direttamente da hylafax:
bin/faxrcvd "recvq/fax000000235.tif" "ttyS1" "000000509" "" "" ""
(ad esempio)

Di conseguenza questo script e' chiamato dal file bin/faxrcvd (bash
script, ultima riga, l'unica modifica fatta rispetto alla versione
orginale hylafax).

Recuperando da bin/faxrcvd solo la variabile $COMMID si esegue::

  bin/hylafax.py -v -s django.settings -i -c $COMMID

es es::

 ../bin/hylafax.py -s office_meinad.settings -c c000061135

Fax in invio
============

Hylafax si comporta (molto) diversamente per i fax in invio.
Ad ogni tentativo di invio viene creato un file di log in log/ .

Soltanto quando l'invio e' terminato viene chiamato lo script notify
con unico argomento il file contenente le informazioni sull'invio.
Questo file e' built-in di hylafax e risiede nella directory doneq/
nel formato q$JOBID (esempio doneq/q890).

Nonostante questo file contenga gia' numerose informazioni sul fax in
questione, si preferisce recuperarne solo il commid per poi parsare
il log 'grezzo' in log/ cosi' come succede per i fax ricevuti.

Exit Status
===========

Passato da bin/notify (solo fax inviati) può essere:

* Killed = job interrotto dall'utente con faxrm
* done = fax inviato
* failed = fax non inviato

.. autofunction:: get_fax

.. .. autofunction:: parse_log

.. .. autofunction:: get_info_from_queue

.. .. autofunction:: parse_row_line


"""

USAGE ="""
  usage: %prog [options]
  -s, --settings=file: settings file eg: jobs.settings
  -d, --dryrun: don't really touch the db
  -v, --verbose: can't you immagine?
  -q, --queue=id: relative queue file path (outgoing fax, ex doneq/q890)
  -c, --commid=id: commid (incoming fax, ex c000003174)
  -r, --root=root: set root dir
  -x, --exit=exit: exit status passed by hylafax
  -t, --to_do=to_do: a chiedere a Giacomo
  -n, --non_so=non_so: a chiedere a Giacomo
"""

import os
import re
import sys
import csv
try:
    from subprocess import getstatusoutput
except ImportError:
    from commands import getstatusoutput
import logging
import logging.handlers
from datetime import datetime
import datetime as d

from django.conf import settings
from django.core.mail import EmailMessage

from jmb.core.utils import optionparse
from jmb.fax.models import Fax, FaxNumber

HYLA_ROOT  = '/var/spool/hylafax/'
LOG_DIR    = HYLA_ROOT + 'log/'
RECV_DIR   = HYLA_ROOT + 'recvq/'
PDF_DIR    = settings.FAX_PATH_DOCUMENTS

DATE_FORMAT='%b %d %H:%M:%S'
today = d.date.today().strftime('%y%m%d')
rec_filename=''

PATTERN_OUT_STATUS = "(status)?(error)?"
out_status = re.compile(PATTERN_OUT_STATUS)

PATTERN_IN_RECV = ".{15,15}.*RECV FAX \(.*\)\: recvq\/(?P<file>.*) from (?P<sender>.*)\,.*, (?P<pages>.*) pages? in (?P<duration>.*)"
PATTERN_IN_RECIPIENT = ".{15,15}.*SESSION BEGIN.* .* (?P<recipient_number>.*)"
PATTERN_IN_DEVICE = ".{15,15}.*recvq/(?P<file>.*fax\d+.tif).*(?P<device>tty\w+?\d+?)\" "
PATTERN_IN_SENDER = '.{15,15}.*CallID.* "(?P<sender_number>.*)" ".*" ".*" ".*"$'

in_recv = re.compile(PATTERN_IN_RECV)
in_recipient = re.compile(PATTERN_IN_RECIPIENT)
in_device = re.compile(PATTERN_IN_DEVICE)
in_sender = re.compile(PATTERN_IN_SENDER)

DATE_FORMAT='%b %d %H:%M:%S'

FAX_VIA_MAIL_NOTIFY_TO_USER = settings.FAX_VIA_MAIL_NOTIFY_TO_USER

MAIL_BODY_SENT = """
Recipient: %s
Subject: %s
Job ID: %s
Sent Date: %s
Sent Confirm: %s
Sent Time: %s
Sent Pages: %s
"""

MAIL_BODY_RCV = """
Sender: %s
Sender Number: %s
Job ID: %s
Received Date: %s
Received Time: %s
Received Pages: %s
"""

# FIXME! un file di log in /tmp!!!!
HYLAFAX_LOG_FILENAME = '/tmp/hylafax.log'



def get_fax():
    """Ritorna una istanza di fax.models.Fax del fax ricevuto o da spedire
    a seconda del valore di ``opt.queue``
    """

    if opt.queue:
        jlogger.debug("Fax Inviato : opt.queue : %s, job : %s" % (opt.queue, opt.queue.split('/q')))
        fax = Fax.objects.get(job=opt.queue.split('/q').pop())
    else:
        jlogger.debug("Fax Ricevuto")
        fax = Fax()
    return fax

def parse_log(fax):
    if opt.queue: # viene passato es. doneq/q10
        log_file_name = os.path.join(HYLA_ROOT, opt.queue)
    else: # viene passato es. c0000010
        log_file_name = os.path.join(LOG_DIR, opt.commid)
        fax.date_create = datetime.fromtimestamp(os.path.getmtime(log_file_name))
    log = open(log_file_name)

    print("Log file name: %s " % log_file_name)
    fax.date_last_modify = datetime.fromtimestamp(os.path.getmtime(log_file_name))
    fax.date_sent = datetime.fromtimestamp(os.path.getmtime(log_file_name))
    if opt.queue:
        info = get_info_from_queue(log)
        if opt.exit == 'killed':
            fax.job = ''
            fax.duration = ''
        else:
            fax.job = 'c' + info['commid']
            if info['commid']:
                duration, sender = get_time_and_sender(info['commid'])
            else:
                duration = sender = None
            fax.duration = duration
            fax.sender = sender
        fax.pages = info['totpages']

        if opt.exit == 'done':
            fax.status = 4
        else:
            fax.status = 5
            fax.error = info['status'] or 'Killed'
    else:
        for line in log:
            parse_raw_line(line)


def get_time_and_sender(filename):
    filename = "c%s" % (filename,)
    f = open(os.path.join(LOG_DIR, filename))
    sender = duration = None

    for line in f:
        m = re.search('SEND FAX.*FROM.*docq.*sent in (?P<time>.*)\)', line)
        if m:
            duration = m.group('time')

        m = re.search('SEND FAX: JOB.*FROM.*@(?P<sender>.*)>.*$', line)
        if m:
            sender = m.group('sender')

    return duration, sender


def get_info_from_queue(log):
    info = {}
    for line in log:
        line = line.rstrip('\n')
        try:
            key = line[:line.find(':')]
            val = line[line.find(':')+1:]
            info[key] = val
        except:
            pass
    return info

# FAX OK
# sdest         #### destinatario
# stty          #### device modem in uscita
# ssend         #### numero mittente
#commid
#totpages

# scommid       #### id log fax (c000000001)
# stime         #### data e ora tentativo spedizione
# sdest         #### destinatario
# ssend         #### mittente
# stty          #### device modem in uscita
# serror        #### errore del fax


def parse_raw_line(line):
    global rec_filename

    m = in_recv.match(line)
    find_information = False

    if m:
        find_information = True
        rec_filename = m.group('file')
        #c = m.group('sender')
        #tmp = c
        #for char in ('.', ' ', '|', '-', '/', '\\'):
        #    tmp = tmp.replace(char, '')
        #tmp = tmp.replace('+','00')
        #if tmp.isdigit():
        #    fax.sender_number = tmp[:16]
        #    fax.sender = c[:100]
        #else:
        fax.sender = m.group('sender')
        fax.pages = m.group('pages')
        fax.duration = m.group('duration')

    m = in_recipient.search(line)
    if m:
        fax.recipient_number = m.group('recipient_number')

    m = in_device.search(line)
    if m:
        fax.device = m.group('device')

        # Ogni tanto ho notato che la riga in_recv non c'e e quindi ad alcuni fax
        # non viene associato il file e il numero di pagine. Quindi se non viene trovato
        # il file nella linea in_recv allora provo anche nella riga in_device
        # che sembra esserci sempre (da qua riesco solo a ricavare il nome del file e non
        # il numero di pagine)
        if not find_information:
            rec_filename = m.group('file')

    m = in_sender.search(line)
    if m:
        fax.sender_number = m.group('sender_number')

    fax.job = opt.commid
    fax.cover = False
    fax.status = 2
    fax.subject = 'fax ricevuto'
    fax.read = 0

### PROGRAM
if __name__ == '__main__':

    opt, args = optionparse.parse(USAGE)
    os.environ['DJANGO_SETTINGS_MODULE'] = opt.settings

    if opt.root:
        HYLA_ROOT = opt.root
        print("Attenzione root impostata a " + opt.root)

    # Set up a specific logger with our desired output level
    jlogger = logging.getLogger('JumboDocLogger')
    jlogger.setLevel(logging.DEBUG)

    # Add the log message handler to the logger
    handler = logging.handlers.RotatingFileHandler(
                  HYLAFAX_LOG_FILENAME, maxBytes=4194304, backupCount=5)

    # create formatter
    formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
    # add formatter to handler
    handler.setFormatter(formatter)
    jlogger.addHandler(handler)

    jlogger.debug("------ INIZIO SCRIPT HYLAFAX -------")


    fax = get_fax()
    parse_log(fax)

    # se fax inviato, la conferma invio la si recupera da fax.status
    if fax.status == 4:
        mail_status = 'OK'
    else:
        mail_status = fax.error

    for i in fax._meta.fields:
        print(i.name, getattr(fax, i.name))
        #print fax.status

    if not opt.dryrun:
        from django.conf import settings

        fax.save()
        if opt.commid:
            fax.file = '%s%s_%s.pdf' % (PDF_DIR, today, fax.id)
            fax.save()
            cmd = "umask 022; tiff2pdf -o %s %s%s" % (fax.file.path, RECV_DIR, rec_filename)
            #cmd = "umask 022; tiff2ps -a %s%s | /usr/bin/ps2pdf - %s" % (RECV_DIR, rec_filename, fax.file.path)
            print("eseguo " + cmd)
            status, output = getstatusoutput(cmd)

        info = {'operator'  : fax.sender_number,
                'pdf_dir'   : PDF_DIR,
                'file'      : fax.file,
                }

        data_fax = fax.date_last_modify.strftime('%d/%m/%Y %H:%M:%S')

        subject_fax = settings.FAX_SUBJECT
        from_fax = settings.FAX_FROM

        recipient_list = FaxNumber.get_notifiers_in(device=fax.device)

        # INVIO MAIL PER FAX RICEVUTI
        if opt.commid:
            if device_number and device_number.send_at_received_fax and recipient_list:
                mittente = ""
                if fax.sender:
                    mittente += "%s" % (fax.sender,)
                if fax.sender_number:
                    mittente += " - %s" % (fax.sender_number,)

                subject = '%sReceived fax of %s from %s' % (subject_fax, data_fax, mittente)
                from_email = 'Report Fax %s' % (from_fax,)
                #hyla_mail_receipt = settings.HYLA_MAIL_RECEIPT
                #recipient_list = hyla_mail_receipt.get(fax.device, [])
                #if recipient_list:
                body_message = MAIL_BODY_RCV % (fax.sender, fax.sender_number, fax.job, data_fax, fax.duration, fax.pages)

                email = EmailMessage(subject, body_message, from_email, recipient_list)
                email.attach_file(fax.file.path)
                email.send()

        # INVIO MAIL PER FAX INVIATI
        else:
            send_sent_mail = False
            sent_recipient_list = set()

            # Se si e' abilitata la notifica via mail per i fax mandati via mail
            # controllo che il fax sia di tipo "mandato via mail", e in caso positivo
            # aggungo nei destinatari il suubmitter del fax.
            if settings.FAX_VIA_MAIL_NOTIFY_TO_USER and fax.sent_by == 'M':
                if fax.submitter.email:
                    sent_recipient_list.add(fax.submitter.email.strip())
                    send_sent_mail = True

            # Se e' stata abilitata anche la conferma di ogni invio dei fax a determinati
            # inidirizzi unisco le varie mail
            if device_number and device_number.send_at_sent_fax and recipient_list:
                sent_recipient_list = sent_recipient_list.union(recipient_list)
                send_sent_mail = True

            if send_sent_mail:
                dest = "%s" % fax.recipient_number
                if fax.recipient:
                    dest = "%s (%s)" % (fax.recipient, fax.recipient_number)
                subject = '%sSent Report - %s - %s - %s' % (subject_fax, dest, fax.subject, data_fax)
                from_email = 'Report Fax %s' % (from_fax,)
                #recipient_list = settings.HYLA_MAIL_RECEIPT
                #if recipient_list:
                body_message = MAIL_BODY_SENT % (dest, fax.subject, fax.job, data_fax, mail_status, fax.duration, fax.pages)

                email = EmailMessage(subject, body_message, from_email, sent_recipient_list)
                email.attach_file(fax.file.path)
                email.send()
